import { ActiveHashRecord, ActiveHashRecordFilter, EagerQueryable, Queryable } from "activehashie";
import { ActiveHashValidation } from "./active_hash_validation";
import { ModelValidationErrorReports } from "./model_validation_error_report";
import { ValidatesMethods } from "./validates_method";
/** バリデート時の絞り込み */
export interface ValidationMethodsCondition<Record extends ActiveHashRecord> {
    /** trueならレコードを含める */
    if?: ActiveHashRecordFilter<Record>;
    /** trueならレコードを除く */
    unless?: ActiveHashRecordFilter<Record>;
}
/** カスタムバリデーター */
export declare type CustomValidator<Record extends ActiveHashRecord> = 
/**
 * @param errors エラーを追加するオブジェクト エラーがあればこのオブジェクトにpushする
 * @param model 絞り込まれたレコード群
 */
(errors: ModelValidationErrorReports<Record>, model: EagerQueryable<Record>) => void;
/** バリデーションを記述する関数に渡されるvalidatesとvalidate */
export declare class ValidationMethods<Record extends ActiveHashRecord> {
    private model;
    private errors;
    /**
     * コンストラクタ
     * @param model 適用するモデル
     * @param validation バリデーション情報を管理するオブジェクト
     */
    constructor(model: Queryable<Record>, validation: ActiveHashValidation);
    /**
     * 汎用のバリデーターでバリデーションする
     *
     * ActiveModel::Validations::ClassMethods#validates相当
     * @param column カラム
     * @param method バリデーション方法
     * @param params バリデーション方法による引数
     * @param condition ifあるいはunlessによる絞り込み
     */
    validates<ValidatesMethod extends keyof ValidatesMethods>(column: keyof Record, method: ValidatesMethod, params: ValidatesMethods[ValidatesMethod], condition?: ValidationMethodsCondition<Record>): void;
    /**
     * カスタムのバリデーション方法でバリデートする
     *
     * ActiveModel::Validations::ClassMethods#validate(ブロック渡し)相当
     * @param validator カスタムバリデーター
     * @param condition ifあるいはunlessによる絞り込み
     */
    validate(validator: CustomValidator<Record>, condition?: ValidationMethodsCondition<Record>): void;
    private filterModelByCondition(condition);
}
